/******************************************************************
*        PoLAR (Portable Library for Augmented Reality)           *
*     Copyright (C) 2015 Inria, Université de Lorraine, CNRS      *
*                                                                 *
* This library is free software; you can redistribute it and/or   *
* modify it under the terms of the GNU General Public License     *
* as published by the Free Software Foundation; either version 3  *
* of the License, or (at your option) any later version.          *
*                                                                 *
* This library is distributed in the hope that it will be useful, *
* but WITHOUT ANY WARRANTY; without even the implied warranty of  *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the    *
* GNU General Public License for more details.                    *
*                                                                 *
*                                                                 *
* You should have received a copy of the GNU General Public       *
* License along with this library.                                *
* If not, see <http://www.gnu.org/licenses/>.                     *
******************************************************************/

#include <QApplication>
#include "ARBallonInterface.h"
#include "props.h"
#include <PoLAR/Image.h>
#include <PoLAR/Util.h>
#include <osg/Geode>
#include <osg/MatrixTransform>
#include <osg/Geometry>
#include <osg/ShapeDrawable>
#include <osg/StateSet>
#include <osg/ColorMask>
#include <osg/PolygonMode>
#include <osgDB/ReadFile>
#include <osgDB/WriteFile>
#include <osgUtil/SmoothingVisitor>
#include <osgUtil/Optimizer>
#include <osg/Texture2D>
#include <iostream>
#include <PoLAR/FrameAxis.h>
#include "MyViewer.h"


int main(int argc,char ** argv)
{
    QApplication app(argc,argv);
    Interface inter;
    osg::ref_ptr<PoLAR::Image_uc> myImage;


    // Charge l'image de fond

    if(PoLAR::
            Util::fileExists("../data/background.jpg"))
        myImage = new PoLAR::Image_uc("../data/background.jpg", true);
    else
    {
        std::cerr << "../data/background.jpg" << ": file not found" << std::endl;
        exit(0);
    }

    // Ajoute l'image chargée au fond
    inter.addImage(myImage, 1);
    double width = myImage->getWidth();
    double height = myImage->getHeight();
    inter.getViewer()->resize(width,height);
    PoLAR::Viewer::ProjectionType pt=PoLAR::Viewer2D3D::VISION;



    // Charge la matrice de projection
    osg::Matrixd P = PoLAR::Util::readProjectionMatrix("../data/matrix.txt");
    inter.setProjection(P, pt);


    // Ajout du modèle
    if(!PoLAR::Util::fileExists("../data/ballon.obj"))
    {
        std::cerr << "Unable to load model" << std::endl;
        exit(0);
    }
    else
    {

        osg::ref_ptr<PoLAR::Object3D> ballon = new PoLAR::Object3D("../data/ballon.obj", true, true, true);
        osgUtil::SmoothingVisitor smooth;
        osgUtil::Optimizer optimizer;
        optimizer.optimize(ballon.get(), osgUtil::Optimizer::ALL_OPTIMIZATIONS);
        ballon->accept(smooth);
        ballon->setName("ballon");
        ballon->translate(3, 2, -1);
        ballon->scale(0.6f);
        inter.addNode(ballon);
        inter.getViewer()->setTrackNode(ballon.get()); // set this object to be tracked by the manipulator

    }


    // Ajout des axes ( rouge-> X, vert-> y et bleu-> z)
    /*PoLAR::FrameAxis *polarAxis= new PoLAR::FrameAxis;
    polarAxis->setLightingOn();
    PoLAR::Object3D *axis = new PoLAR::Object3D(polarAxis,true);
    axis->setName("FrameAxis");
    axis->setEditOn();
    axis->translate(0,0,0);
    axis->scale(100.0f);
    inter.addNode(axis);*/

    //ajout de l'objet animé
    /*
        if(!PoLAR::Util::fileExists("../Examples/data/ballon.osgt"))
        {
            std::cerr << "Unable to load model" << std::endl;
            exit(0);
        }
        else
        {

            PoLAR::Viewer viewer;
            osg::ref_ptr<PoLAR::AnimatedObject3D> ballon = new PoLAR::AnimatedObject3D("../Examples/data/ballon.osgt");
            ballon->translate(0,0,-7);
            ballon->scale(0.2f);
            viewer.addObject3D(ballon.get());


        }
        */


    inter.getViewer()->center();
    inter.show();



    return app.exec();
}
